# Generated by Django 4.2.11 on 2024-03-27 19:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0061_alter_historicalicpreferral_site_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="icpreferral",
            name="site",
        ),
        migrations.RemoveField(
            model_name="icpreferral",
            name="subject_screening",
        ),
        migrations.DeleteModel(
            name="HistoricalIcpReferral",
        ),
        migrations.DeleteModel(
            name="IcpReferral",
        ),
    ]
