<h5>Use the following criteria to help answer the questions below. Values are in mmol/L.</h5>
<P>
<BR>FBG≥7.0 and OGTT≥11.1: Yes, endpoint reached
<BR>FBG<7v and OGTT≥11.1: Yes, endpoint reached
<BR>FBG≥7.0 and OGTT<11.1: Not today, repeat FBG in 1 week<BR>
</P>