# Generated by Django 4.2 on 2024-02-07 21:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0161_alter_birthoutcomes_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupexamination",
            name="abdominal_tenderness",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Abdominal tenderness",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="enlarged_liver",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Enlarged liver",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="jaundice",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Jaundice",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="abdominal_tenderness",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Abdominal tenderness",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="enlarged_liver",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Enlarged liver",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="jaundice",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_evaluated", "Not evaluated")],
                max_length=25,
                verbose_name="Jaundice",
            ),
        ),
    ]
