# Generated by Django 2.2.6 on 2019-10-20 03:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("meta_screening", "0001_initial")]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="already_fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Has the patient come to the clinic today already fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="already_fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Has the patient come to the clinic today already fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="already_fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Has the patient come to the clinic today already fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="already_fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Has the patient come to the clinic today already fasted?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="already_fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Has the patient come to the clinic today already fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="You may use today's date if the patient has already fasted and has agreed to complete the second stage of screening today",
                null=True,
                verbose_name="Appointment date for second stage of screening",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="You may use today's date if the patient has already fasted and has agreed to complete the second stage of screening today",
                null=True,
                verbose_name="Appointment date for second stage of screening",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="You may use today's date if the patient has already fasted and has agreed to complete the second stage of screening today",
                null=True,
                verbose_name="Appointment date for second stage of screening",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="You may use today's date if the patient has already fasted and has agreed to complete the second stage of screening today",
                null=True,
                verbose_name="Appointment date for second stage of screening",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="You may use today's date if the patient has already fasted and has agreed to complete the second stage of screening today",
                null=True,
                verbose_name="Appointment date for second stage of screening",
            ),
        ),
    ]
