# Generated by Django 4.1 on 2022-08-21 18:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "meta_screening",
            "0055_alter_historicalscreeningpartone_creatinine_value_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="N/A",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="N/A",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="N/A",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="N/A",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="N/A",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
    ]
